@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017, 2018 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <martin@kollix.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <PagerButton.hxx>
@@ -32,6 +20,7 @@
 #include <QDebug>
 
 #include <KWinCompat.hxx>
+#include <KWindowInfo>
 #include <KIconLoader>
 #include <KIconEffect>
 
@@ -136,9 +125,7 @@ void PagerButton::createPixmap()
     {
       firstPixmap = KWinCompat::icon(wid, 22, 22, true);
 
-      KIconEffect effect;
-      firstPixmap = effect.apply(firstPixmap, KIconEffect::DeSaturate, 0, QColor(), true);
-
+      KIconEffect::semiTransparent(firstPixmap);
       break;
     }
   }
