@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2021 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <martin@kollix.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <SysTrayItem.hxx>
@@ -26,7 +14,6 @@
 #include <QScreen>
 #include <QIcon>
 
-#include <KWindowSystem>
 #include <KIconLoader>
 
 //--------------------------------------------------------------------------------
@@ -71,7 +58,7 @@ void SysTrayItem::showDetailsList()
   point.setY(screen.bottom() - size.height());
   detailsList->move(point);
   detailsList->show();
-  KWindowSystem::raiseWindow(detailsList->winId());
+  detailsList->raise();
 }
 
 //--------------------------------------------------------------------------------
