@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017 - 2021 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <martin@kollix.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <SysTrayNotifyItem.hxx>
@@ -30,6 +18,7 @@
 #include <QContextMenuEvent>
 #include <QPainter>
 
+#include <DBusTypes.hxx>
 #include <KWinCompat.hxx>
 
 //--------------------------------------------------------------------------------
@@ -38,6 +27,8 @@
 SysTrayNotifyItem::SysTrayNotifyItem(QWidget *parent, const QString &service, const QString &path)
   : QLabel("?", parent)
 {
+  setContextMenuPolicy(Qt::PreventContextMenu);
+
   // make sure several "New*" signals from dbus just trigger one fetchData() call
   fetchTimer.setSingleShot(true);
   fetchTimer.setInterval(500);
@@ -51,6 +42,7 @@ SysTrayNotifyItem::SysTrayNotifyItem(QWidget *parent, const QString &service, co
   connect(dbus, &OrgKdeStatusNotifierItem::NewStatus,        this, &SysTrayNotifyItem::startTimer);
   connect(dbus, &OrgKdeStatusNotifierItem::NewTitle,         this, &SysTrayNotifyItem::startTimer);
   connect(dbus, &OrgKdeStatusNotifierItem::NewToolTip,       this, &SysTrayNotifyItem::startTimer);
+  connect(dbus, &OrgKdeStatusNotifierItem::NewMenu,          this, &SysTrayNotifyItem::startTimer);
 
   fetchData();
 }
@@ -66,6 +58,8 @@ void SysTrayNotifyItem::startTimer()
 
 void SysTrayNotifyItem::fetchData()
 {
+  //qDebug() << __FUNCTION__ << dbus->service() << dbus->path() << dbus->interface();
+
   QDBusMessage msg =
       QDBusMessage::createMethodCall(dbus->service(), dbus->path(),
                                      "org.freedesktop.DBus.Properties",
@@ -82,12 +76,16 @@ void SysTrayNotifyItem::fetchData()
 
 void SysTrayNotifyItem::fetchDataReply(QDBusPendingCallWatcher *w)
 {
+  //qDebug() << "--------------------";
+  //qDebug() << __FUNCTION__ << dbus->title() << dbus->service() << dbus->path() << dbus->interface();
+
   w->deleteLater();
   QDBusPendingReply<QVariantMap> reply = *w;
 
   if ( reply.isError() )
   {
-    //qDebug() << dbus->service() << reply.error();
+    //qDebug() << "ERROR" << dbus->service() << reply.error();
+    emit initialized(this, Result::Failed);
     deleteLater();
     return;
   }
@@ -177,14 +175,16 @@ void SysTrayNotifyItem::fetchDataReply(QDBusPendingCallWatcher *w)
 
   QString tip(dbus->title());
 
-  if ( //!toolTip.icon.isEmpty() ||
-       //!toolTip.image.isNull() ||
-       !toolTip.title.isEmpty() ||
-       !toolTip.subTitle.isEmpty() )
+  if ( !toolTip.title.isEmpty() )
   {
-    tip = QString("<html><center><b>%1</b><br>%2</center></html>")
-                  .arg(toolTip.title)
-                  .arg(toolTip.subTitle);
+    if ( toolTip.subTitle.isEmpty() )
+      tip = QString("<html>%1</html>").arg(toolTip.title);
+    else
+    {
+      tip = QString("<html><center><b>%1</b><br>%2</center></html>")
+                    .arg(toolTip.title)
+                    .arg(toolTip.subTitle);
+    }
   }
 
   setToolTip(tip);
@@ -197,7 +197,7 @@ void SysTrayNotifyItem::fetchDataReply(QDBusPendingCallWatcher *w)
       hide();
   }
 
-  emit initialized(this);
+  emit initialized(this, Result::Ok);
 }
 
 //--------------------------------------------------------------------------------
@@ -271,23 +271,23 @@ void SysTrayNotifyItem::mouseReleaseEvent(QMouseEvent *event)
 
   if ( event->button() == Qt::LeftButton )
   {
-    QDBusPendingReply<> reply = dbus->Activate(event->globalPos().x(), event->globalPos().y());
+    QDBusPendingReply<> reply = dbus->Activate(event->globalPosition().x(), event->globalPosition().y());
     reply.waitForFinished();
 
     if ( !reply.isError() && dbus->windowId() )
     {
       WId wid = dbus->windowId();
-      KWindowSystem::raiseWindow(wid);
       KWinCompat::forceActiveWindow(wid);
     }
   }
+  else if ( event->button() == Qt::MiddleButton )
+  {
+    dbus->SecondaryActivate(event->globalPosition().x(), event->globalPosition().y());
+  }
   else if ( event->button() == Qt::RightButton )
   {
-    QDBusPendingReply<> reply = dbus->ContextMenu(event->globalPos().x(), event->globalPos().y());
-    reply.waitForFinished();
-
-    if ( reply.isError() && (reply.error().type() == QDBusError::UnknownMethod) &&
-         !menuPath.isEmpty() )
+    //qDebug() << dbus->service() << menuPath;
+    if ( !menuPath.isEmpty() && (menuPath != "/NO_DBUSMENU") )
     {
       QDBusMessage msg =
           QDBusMessage::createMethodCall(dbus->service(), menuPath,
@@ -302,6 +302,10 @@ void SysTrayNotifyItem::mouseReleaseEvent(QMouseEvent *event)
       QDBusPendingCallWatcher *pendingCallWatcher = new QDBusPendingCallWatcher(call, this);
       connect(pendingCallWatcher, &QDBusPendingCallWatcher::finished, this, &SysTrayNotifyItem::menuLayoutReply);
     }
+    else
+    {
+      dbus->ContextMenu(event->globalPosition().x(), event->globalPosition().y());
+    }
   }
 }
 
@@ -311,16 +315,15 @@ void SysTrayNotifyItem::menuLayoutReply(QDBusPendingCallWatcher *w)
 {
   w->deleteLater();
 
-  QDBusMenuItem::registerDBusTypes();
-  QDBusPendingReply<unsigned int, QDBusMenuLayoutItem> reply = *w;
+  qDBusRegisterMetaType<DBusMenuLayoutItem>();
+  QDBusPendingReply<unsigned int, DBusMenuLayoutItem> reply = *w;
 
   if ( reply.isError() )
   {
     //qDebug() << dbus->service() << reply.error();
     return;
   }
-
-  QDBusMenuLayoutItem item = reply.argumentAt<1>();
+  DBusMenuLayoutItem item = reply.argumentAt<1>();
 
   QMenu menu;
   fillMenu(menu, item);
@@ -346,7 +349,7 @@ void SysTrayNotifyItem::menuLayoutReply(QDBusPendingCallWatcher *w)
 //--------------------------------------------------------------------------------
 // https://github.com/gnustep/libs-dbuskit/blob/master/Bundles/DBusMenu/com.canonical.dbusmenu.xml
 
-void SysTrayNotifyItem::fillMenu(QMenu &menu, const QDBusMenuLayoutItem &item)
+void SysTrayNotifyItem::fillMenu(QMenu &menu, const DBusMenuLayoutItem &item)
 {
   QString type = item.m_properties.value("type", "standard").toString();
 
@@ -409,7 +412,7 @@ void SysTrayNotifyItem::fillMenu(QMenu &menu, const QDBusMenuLayoutItem &item)
       {
         QMenu *submenu = title.isEmpty() ? &menu : menu.addMenu(icon, title);
 
-        for (const QDBusMenuLayoutItem &subItem : item.m_children)
+        for (const DBusMenuLayoutItem &subItem : item.m_children)
         {
           fillMenu(*submenu, subItem);
 
