@@ -1,21 +1,9 @@
-// SPDX-License-Identifier: GPL-3.0-or-later
 /*
-  Copyright 2017, 2018, 2019 Martin Koller, kollix@aon.at
-
   This file is part of liquidshell.
 
-  liquidshell is free software: you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation, either version 3 of the License, or
-  (at your option) any later version.
+  SPDX-FileCopyrightText: 2017 - 2024 Martin Koller <martin@kollix.at>
 
-  liquidshell is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with liquidshell.  If not, see <http://www.gnu.org/licenses/>.
+  SPDX-License-Identifier: GPL-3.0-or-later
 */
 
 #include <TaskBarButton.hxx>
@@ -28,7 +16,6 @@
 #include <QStyle>
 #include <QStyleOptionButton>
 #include <QPainter>
-#include <QX11Info>
 #include <QMenu>
 #include <QDragEnterEvent>
 #include <QDragLeaveEvent>
@@ -41,8 +28,7 @@
 #include <KSqueezedTextLabel>
 #include <KColorScheme>
 #include <KLocalizedString>
-
-#include <netwm.h>
+#include <KWindowInfo>
 
 //--------------------------------------------------------------------------------
 
@@ -54,8 +40,7 @@ TaskBarButton::TaskBarButton(WId theWid)
   setAcceptDrops(true);
   dragDropTimer.setSingleShot(true);
   dragDropTimer.setInterval(1000);
-  connect(&dragDropTimer, &QTimer::timeout,
-          [this]() { KWindowSystem::raiseWindow(wid); KWinCompat::forceActiveWindow(wid); });
+  connect(&dragDropTimer, &QTimer::timeout, [this]() { KWinCompat::forceActiveWindow(wid); });
 
   QHBoxLayout *hbox = new QHBoxLayout(this);
   hbox->setContentsMargins(QMargins(4, 2, 4, 2));
@@ -74,7 +59,7 @@ TaskBarButton::TaskBarButton(WId theWid)
   fill();
   setBackground();
 
-  connect(KWindowSystem::self(), SIGNAL(windowChanged(WId, NET::Properties, NET::Properties2)),
+  connect(KWinCompat::self(), SIGNAL(windowChanged(WId, NET::Properties, NET::Properties2)),
           this, SLOT(windowChanged(WId, NET::Properties, NET::Properties2)));
 
   connect(KWinCompat::self(), &KWinCompat::activeWindowChanged,
@@ -132,12 +117,12 @@ void TaskBarButton::mousePressEvent(QMouseEvent *event)
     menu->addAction(QIcon::fromTheme("window-close"), i18n("Close"),
                     [this]()
                     {
-                      NETRootInfo ri(QX11Info::connection(), NET::CloseWindow);
+                      NETRootInfo ri(qApp->nativeInterface<QNativeInterface::QX11Application>()->connection(), NET::CloseWindow);
                       ri.closeWindowRequest(wid);
                     }
                    );
 
-    menu->exec(event->globalPos());
+    menu->exec(event->globalPosition().toPoint());
     delete menu;
   }
 }
@@ -155,11 +140,7 @@ void TaskBarButton::mouseMoveEvent(QMouseEvent *event)
     QMimeData *mimeData = new QMimeData;
     mimeData->setData("application/x-winId", QByteArray::number(static_cast<int>(wid)));
     drag->setMimeData(mimeData);
-#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
-    drag->setPixmap(iconLabel->pixmap(Qt::ReturnByValue));
-#else
-    drag->setPixmap(*(iconLabel->pixmap()));
-#endif
+    drag->setPixmap(iconLabel->pixmap());
     drag->exec();
   }
 }
@@ -253,11 +234,11 @@ void TaskBarButton::dropEvent(QDropEvent *event)
 
 void TaskBarButton::updateWMGeometry()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
-  NETWinInfo info(QX11Info::connection(), wid, QX11Info::appRootWindow(), NET::Properties(), NET::Properties2());
-#else
-  NETWinInfo info(QX11Info::connection(), wid, QX11Info::appRootWindow(), 0, 0);
-#endif
+  NETWinInfo info(qApp->nativeInterface<QNativeInterface::QX11Application>()->connection(), wid,
+                  //QX11Info::appRootWindow(),
+                  NETRootInfo(qApp->nativeInterface<QNativeInterface::QX11Application>()->connection(),
+                              NET::Properties()).rootWindow(),
+                  NET::Properties(), NET::Properties2());
 
   NETRect rect;
   QPoint globalPos = mapToGlobal(QPoint(0, 0));
